@@ -138,7 +138,11 @@ class CmdUploadDeb(CmdUpload):
             # upload deb file
             upload_deb_cmd = 'ret=$(curl -u "'+ conanfile.apt_user +'" -H "Content-Type: multipart/form-data" --data-binary "@' \
                                 + deb_file + '" "' + conanfile.apt_server + '" -f)'
-            conanfile.run(upload_deb_cmd)
+            try:
+                conanfile.run(upload_deb_cmd)
+                self._output.success("Uploaded %s to remote apt server '%s' successfully." % (str(deb_file), conanfile.apt_server))
+            except Exception as e:
+                self._output.error("Failed to upload current deb. Error: " + str(e))
         else:
             print("Warning: deb file is not exist")
 
