@@ -6,7 +6,7 @@ class Sense2File(ConanFile):
 
     deb_control = None
     deb_changelog = None
-    deb_install_folder = None
+    deb_install_path = None
     
     apt_user = None
     apt_server = None
